@@ -5,12 +5,16 @@
  * This file defines Ingo's external API interface. Other applications
  * can interact with Ingo through this API.
  *
- * $Horde: ingo/lib/api.php,v 1.16.12.1 2005/01/24 10:31:57 jan Exp $
+ * $Horde: ingo/lib/api.php,v 1.16.12.4 2006/01/31 20:00:24 jan Exp $
  *
- * See the enclosed file COPYING for license information (GPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file LICENSE for license information (ASL).  If you
+ * did not receive this file, see http://www.horde.org/licenses/asl.php.
  */
 
+$_services['perms'] = array(
+    'args' => array(),
+    'type' => '{urn:horde}stringArray');
+
 $_services['blacklistFrom'] = array(
     'args' => array('addresses' => '{urn:horde}stringArray'),
     'type' => 'boolean'
@@ -43,6 +47,19 @@ $_services['showFilters'] = array(
     'link' => '%application%/filters.php'
 );
 
+function _ingo_perms()
+{
+    $perms = array();
+    $perms['tree']['ingo']['allow_rules'] = false;
+    $perms['title']['ingo:allow_rules'] = _("Allow Rules");
+    $perms['type']['ingo:allow_rules'] = 'boolean';
+    $perms['tree']['ingo']['max_rules'] = false;
+    $perms['title']['ingo:max_rules'] = _("Maximum Number of Rules");
+    $perms['type']['ingo:max_rules'] = 'int';
+
+    return $perms;
+}
+
 function _ingo_blacklistFrom($addresses)
 {
     require_once dirname(__FILE__) . '/../lib/base.php';
@@ -57,13 +74,16 @@ function _ingo_blacklistFrom($addresses)
     }
 
     if (!empty($addresses)) {
-        $blacklist = $ingo_storage->retrieve(INGO_STORAGE_ACTION_BLACKLIST);
+        $blacklist = &$ingo_storage->retrieve(INGO_STORAGE_ACTION_BLACKLIST);
         $ret = $blacklist->setBlacklist(array_merge($blacklist->getBlacklist(), $addresses));
         if (is_a($ret, 'PEAR_Error')) {
             $GLOBALS['notification']->push($ret, $ret->getCode());
         } else {
             $ingo_storage->store($blacklist);
             Ingo::updateScript();
+            foreach ($addresses as $from) {
+                $GLOBALS['notification']->push(sprintf(_("The address \"%s\" has been added to your blacklist."), $from));
+            }
         }
     }
 }
@@ -73,13 +93,16 @@ function _ingo_whitelistFrom($addresses)
     require_once dirname(__FILE__) . '/../lib/base.php';
     global $ingo_storage;
 
-    $whitelist = $ingo_storage->retrieve(INGO_STORAGE_ACTION_WHITELIST);
+    $whitelist = &$ingo_storage->retrieve(INGO_STORAGE_ACTION_WHITELIST);
     $ret = $whitelist->setWhitelist(array_merge($whitelist->getWhitelist(), $addresses));
     if (is_a($ret, 'PEAR_Error')) {
         $GLOBALS['notification']->push($ret, $ret->getCode());
     } else {
         $ingo_storage->store($whitelist);
         Ingo::updateScript();
+        foreach ($addresses as $from) {
+            $GLOBALS['notification']->push(sprintf(_("The address \"%s\" has been added to your whitelist."), $from));
+        }
     }
 }
 
